<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>FractalGeneratorApp</name>
    <message>
        <location filename="fractalgenerator.cc" line="100"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="102"/>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="103"/>
        <source>&amp;Open</source>
        <translation>&amp;Öffnen</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="104"/>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="105"/>
        <source>Save As ...</source>
        <oldsource>Save As</oldsource>
        <translation>Speichern unter ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="107"/>
        <source>&amp;Export ...</source>
        <oldsource>&amp;Export Image</oldsource>
        <translation>&amp;Exportieren ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="108"/>
        <source>&amp;Print ...</source>
        <oldsource>Print &amp;Image</oldsource>
        <translation>&amp;Drucken ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="110"/>
        <source>&amp;Close</source>
        <translation>Schließe&amp;n</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="111"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="114"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="116"/>
        <source>&amp;Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="117"/>
        <source>Copy Selection</source>
        <translation>Auswahl kopieren</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="120"/>
        <source>Zoom &amp;In</source>
        <translation>Hineinzoomen</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="122"/>
        <source>Zoom &amp;Back</source>
        <translation>Herauszoomen</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="125"/>
        <source>&amp;Reset Zoom</source>
        <translation>Zoom zurücksetzen</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="128"/>
        <source>&amp;Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="131"/>
        <source>Custom Image Size</source>
        <translation>Bildgröße manuell setzen</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="134"/>
        <source>Swap Width and Height</source>
        <translation>Vertausche Breite und Höhe</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="200"/>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="441"/>
        <location filename="fractalgenerator.cc" line="454"/>
        <source>Image Size</source>
        <translation>Bildgröße</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="155"/>
        <source>&amp;Algorithm</source>
        <translation>&amp;Algorithmus</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="157"/>
        <source>Configure Algorithm ...</source>
        <oldsource>Configure Algorithm</oldsource>
        <translation>Algorithmus konfigurieren ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="177"/>
        <source>&amp;Color Scheme</source>
        <translation>&amp;Farbschema</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="197"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="199"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="205"/>
        <source>Fractal.pdf</source>
        <translation>Fraktal.pdf</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="207"/>
        <source>Welcome to FractGen!</source>
        <oldsource>Welcome to Fractal Generator!</oldsource>
        <translation>Willkommen zu FractGen!</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="237"/>
        <source>Opening file ...</source>
        <oldsource>Opening file...</oldsource>
        <translation>Öffne Datei ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="239"/>
        <source>Open File ...</source>
        <translation>Öffnen ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="241"/>
        <location filename="fractalgenerator.cc" line="275"/>
        <source>FractGen File (*.fsf)</source>
        <translation>FractGen-Datei (*.fsf)</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="454"/>
        <source>Invalid image size!</source>
        <translation>Ungültige Bildgröße!</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="245"/>
        <location filename="fractalgenerator.cc" line="264"/>
        <location filename="fractalgenerator.cc" line="279"/>
        <location filename="fractalgenerator.cc" line="298"/>
        <location filename="fractalgenerator.cc" line="319"/>
        <location filename="fractalgenerator.cc" line="364"/>
        <location filename="fractalgenerator.cc" line="416"/>
        <location filename="fractalgenerator.cc" line="462"/>
        <source>Ready</source>
        <oldsource>Ready.</oldsource>
        <translation>Bereit</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="271"/>
        <source>Saving file as ...</source>
        <translation>Speichere Datei unter ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="273"/>
        <source>Save File ...</source>
        <translation>Datei speichern ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="252"/>
        <source>Saving file...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="256"/>
        <source>Overwrite existing file?</source>
        <oldsource>Overwrite existing file </oldsource>
        <translation>Bestehende Datei überschreiben?</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="286"/>
        <source>Exporting Image ...</source>
        <translation>Exportiere Bild ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="288"/>
        <source>Export Image</source>
        <translation>Bild exportieren</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="312"/>
        <source>Printing...</source>
        <translation>Drucke ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="431"/>
        <source>Changing Image Size ...</source>
        <translation>Ändere Bildgröße ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="442"/>
        <source>Please enter new size in the format x*y:</source>
        <translation>Bitte neue Bildgröße im Format x*y eingeben:</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="360"/>
        <source>Changing Options ...</source>
        <translation>Ändere Optionen ...</translation>
    </message>
    <message>
        <location filename="fractalgenerator.cc" line="413"/>
        <source>Click middle mouse button or choose &quot;View -&gt; Zoom In&quot; to magnify selected area!</source>
        <translation>Mittlere Maustaste drücken oder &quot;Ansicht -&gt; Vergößern&quot; wählen zum Vergrößern des ausgewählten Bereiches!</translation>
    </message>
</context>
<context>
    <name>FractalGeneratorDoc</name>
    <message>
        <location filename="fractalgeneratordoc.cc" line="62"/>
        <source>Unnamed.fsf</source>
        <translation>Unbenannt.fsf</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="94"/>
        <location filename="fractalgeneratordoc.cc" line="104"/>
        <location filename="fractalgeneratordoc.cc" line="121"/>
        <location filename="fractalgeneratordoc.cc" line="135"/>
        <source>Open File Failure</source>
        <translation>Fehler beim Öffnen der Datei</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="96"/>
        <location filename="fractalgeneratordoc.cc" line="106"/>
        <source>Line: </source>
        <translation>Zeile:</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="97"/>
        <location filename="fractalgeneratordoc.cc" line="107"/>
        <source>Column: </source>
        <translation>Spalte:</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="122"/>
        <source>Invalid AlgorithmName entry:</source>
        <translation>Ungültiger Eintrag für AlgorithmName:</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="136"/>
        <source>Invalid ColorSchemeName entry:</source>
        <translation>Ungültiger Eintrag für ColorSchemeName:</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="174"/>
        <source>Open File Warning</source>
        <translation>Warnung beim Öffnen der Datei</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="175"/>
        <source>Skipping unknown entry:</source>
        <translation>Überspringe unbekannten Eintrag:</translation>
    </message>
    <message>
        <location filename="fractalgeneratordoc.cc" line="277"/>
        <source>Save File Failure</source>
        <translation>Fehler beim Schreiben der Datei</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="optionsdialog.cc" line="34"/>
        <source>Fractal Algorithm Options</source>
        <translation>Einstellungen für Fraktalalgorithmus</translation>
    </message>
    <message>
        <location filename="optionsdialog.cc" line="42"/>
        <source>Parameter Name</source>
        <translation>Parametername</translation>
    </message>
    <message>
        <location filename="optionsdialog.cc" line="46"/>
        <source>Parameter Value</source>
        <translation>Parameterwert</translation>
    </message>
    <message>
        <location filename="optionsdialog.cc" line="72"/>
        <source>&amp;Okay</source>
        <translation>&amp;Okay</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="clifractgen.cc" line="46"/>
        <source>FSF input file.</source>
        <oldsource>FSF input file</oldsource>
        <translation>FSF-Eingabedatei.</translation>
    </message>
    <message>
        <location filename="clifractgen.cc" line="48"/>
        <source>Graphics output file.</source>
        <oldsource>Graphics output file</oldsource>
        <translation>Grafikausgabedatei.</translation>
    </message>
    <message>
        <location filename="clifractgen.cc" line="53"/>
        <source>Width.</source>
        <oldsource>Width</oldsource>
        <translation>Breite.</translation>
    </message>
    <message>
        <location filename="clifractgen.cc" line="61"/>
        <source>Height.</source>
        <oldsource>Height</oldsource>
        <translation>Höhe.</translation>
    </message>
    <message>
        <location filename="clifractgen.cc" line="69"/>
        <source>Maximum number of iterations.</source>
        <oldsource>Maximum number of iterations</oldsource>
        <translation>Maximale Anzahl von Iterationen.</translation>
    </message>
</context>
</TS>
